@@ -217,16 +217,20 @@ paneller.Solid.solve.__doc__='''solve(damper=0.0, target=np.array([])wakeiter=0,
 computes solution and surface forces, with local panel transpiration (to enable viscid-inviscid coupling) input to \'target\'.
 if len(target)==0: target=np.zeros(npanels). A Thikhonov regularization is performed with damping coefficient \'damper\' if damper floating point kwarg is set as non-zero, thus solving even an ill-conditioned 
 AIC matrix. Wake iterations (with their number defined by wakeiter kwarg) are performed according to provided freestream arguments'''
-paneller.Solid.calcpress.__doc__='''calcpress(Uinf=1.0): calculates Solid.Cps based on Solid.vbar and Solid.delphi'''
+paneller.Solid.calcpress.__doc__='''calcpress(Uinf=1.0, gamma=1.4, M=0.0): calculates Solid.Cps based on Solid.vbar and Solid.delphi'''
 paneller.Solid.calcforces.__doc__='''calcforces(): calculates local forces and moments on each panel, based on Solid.Cps and Solid.Cfs'''
-paneller.Solid.calc_derivative.__doc__='''calc_derivative(Uinf, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, par='a'): calculates derivatives in local pressure coefficients as array dCps, differentiated by
-freestream parameter in string variable \'par\'. Returns array of shape (npanels)'''
+paneller.Solid.calc_derivative_dv.__doc__='''calc_derivative_dv(Uinf, dvdksi, M=0.0, gamma=1.4): calculates derivatives in local pressure coefficients as array dCps, based on input
+local velocity variations (dvdksi, shape (npanels, 3)). Returns array of shape (npanels)'''
+paneller.Solid.calc_derivative_dn.__doc__='''calc_derivative_dn(Uinf, dvdksi, M=0.0, gamma=1.4): calculates derivatives in local pressure coefficients as array dCps, based on input
+local normal velocity variations (dndksi, shape (npanels)). Returns array of shape (npanels)'''
 paneller.Solid.plotgeometry.__doc__='''plotgeometry(xlim=[], ylim=[], zlim=[], velfield=True, factor=1.0): plots solid\'s panelling as wireframe, with plot limits set by x, y, zlim arguments if non-empty.
 if velfield==True, plots vectors correspondent to each panel\'s local velocity vector multiplier by a factor (\'factor\' kwarg) for easier visualization of velocity field'''
 paneller.Solid.plotnormals.__doc__='''plotnormals(xlim=[], ylim=[], zlim=[], factor=1.0): plots panels as wireframe and their normal vectors p.nvector, scaled by factor kwarg so as to ease visualization.
 Sets plot limits if provided in non-empty kwargs'''
-paneller.Solid.eulersolve.__doc__='''eulersolve(target=np.array([]), a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, Uinf=1.0, echo=True, beta=0.0): computes complete euler solution through calls for 
-Solid.genvbar, gennvv, genaicm, solve, calcpress and calcforces. Uses given freestream parameters and outputs time duration report if echo==True. Applies PG correction factor beta'''
+paneller.Solid.eulersolve.__doc__='''eulersolve(self, target=np.array([]), Uinf=1.0, M=0.0, gamma=1.4, beta=1.0, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, echo=True, \
+        wakeiter=0, tolerance=1e-5): computes complete euler solution through calls for 
+Solid.genvbar, gennvv, genaicm, solve, calcpress and calcforces. Uses given freestream parameters and outputs time duration report if echo==True. Applies PG correction factor beta.
+M and gamma used for Cp compressibility corrections'''
 paneller.Solid.addorder.__doc__='''addorder(self, queue, colmat, ind1, ind2): adds order for multiprocessing queue for subprocess_genaicm function to calculate AIC matrix\'s columns ind1 to ind2'''
 paneller.Solid.panel_calcSn.__doc__='''panel_calcSn(p): recalculates area and normal vector for panel p'''
 paneller.Solid.PG_apply.__doc__='''PG_apply(beta, a, b): applies PG correction to all panel and line positions (including wake panels) according to correction factor beta and freestream parameters a and b'''
@@ -723,7 +727,9 @@ CG: center of gravity of the aircraft at hand
 CX, CY, CZ, CL, CD, Cm, Cn, Cl: adimensional force coefficients for the whole configuration, with moments centered about the given CG
 dCX, dCY, ...: variation in adimensional force coefficients due to viscous corrections
 Sref, cref, bref, AR: reference quantities for calculation of adimensional coefficients
-a, b, p, q, r, Uinf: freestream parameters
+a, b, p, q, r, Uinf, M: freestream parameters
+rho, mu, gamma, g: environment parameters
+m, Ixx, Iyy, Izz, Ixy, Ixz, Iyz: mass parameters
 plotlim: maximum dimension of the aircraft stretching from the origin of its coordinate system, used as default for plot_input() and plotgeometry() limits
 controlset: dictionary reporting all control degrees of freedom for the aircraft, as generated by wing quadrant constructors
 forcesavailable, stabavailable, massavailable, hascorrections: whether, respectively, forces, stability derivatives, mass information and viscous corrections are available for the aircraft at hand
@@ -736,6 +742,8 @@ methods
 
 __init__
 parameter_report
+addmass
+dynamic_simulation
 balance
 transp_byvec
 transp_to_cg
@@ -788,6 +796,14 @@ aircraft.aircraft.plot_input.__doc__='''plot_input(xlim=[], ylim=[], zlim=[]): p
 is provided'''
 aircraft.aircraft.plotgeometry.__doc__='''plotgeometry(xlim=[], ylim=[], zlim=[], factor=1.0, velfield=True): plots the aircraft\'s panelling as a wireframe. If velfield is set to True, local velocities are
 also drawn as vectors (multiplied by scaling factor kwarg for easier visualization)'''
+aircraft.aircraft.addmass.__doc__='''addmass(m=0.0, Ixx=0.0, Iyy=0.0, Izz=0.0, Ixy=0.0, Ixz=0.0, Iyz=0.0, echo=True): adds mass variables to simulation according to kwargs. runs aircraft.parameter_report()
+if echo kwarg is set to True'''
+aircraft.aircraft.dynamic_simulation.__doc__='''dynamic_simulation(nstep=2e5, dt=1e-4, start_point=np.array([0.0, 0.0, 0.0]), perturbations={}, trim=True, visc=True, onboard=np.zeros(3)): 
+executes dynamic simulation according to time step dt with nstep finite difference time steps. Perturbations is a dictionary which should include disturbances between phi, theta, psi, u, v, w, p, q, r. Angles 
+are all accounted in radians. Returns external_history, alpha_history, beta_history, euler_history, time_history: external history is a shape (nstep, 3) array containing evolution of aircraft position
+(in external coordinate system) in time (array time_history). beta history and alpha history are arrays reporting the evolution of alpha and beta perturbations in time, in radians. To add onboard moment addition
+for engines, use argument onboard. All coordinate systems (except for the one reported as external in return values) are stability coordinate systems (z, x axis inverted). If trim is set to True, 
+coefficients for analysis angle of attack and sideslip are set to zero to simulate a trimmed aircraft'''
 
 aerodynamic_output.__doc__='''
 Module containing functions for plotting aerodynamic results
